Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2442)

Unified Diff: buildbot/buildbot_standard.py

Issue 2164993002: Update linux-syscall-support to 3f6478ac95edf86cd3da300c2c0d34a438f5dbeb (Closed) Base URL: https://chromium.googlesource.com/native_client/src/native_client.git@master
Patch Set: Remove bogus slash Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « DEPS ('k') | src/trusted/service_runtime/linux/nacl_bootstrap.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: buildbot/buildbot_standard.py
diff --git a/buildbot/buildbot_standard.py b/buildbot/buildbot_standard.py
index 532bb02929ab229a736c23a50dc3bffc5aabf44c..e492041a2f483b06ddc7a99bd682aee3e95f03b9 100644
--- a/buildbot/buildbot_standard.py
+++ b/buildbot/buildbot_standard.py
@@ -334,7 +334,8 @@ def BuildScript(status, context):
CommandGclientRunhooks(context)
# Always update Clang. On Linux and Mac, it's the default for the GN build.
# On Windows, we do a second Clang GN build.
with Step('update_clang', status):
Command(context, cmd=[sys.executable, '../tools/clang/scripts/update.py'])
@@ -394,9 +395,25 @@ def BuildScript(status, context):
if context['use_breakpad_tools']:
with Step('breakpad configure', status):
Command(context, cmd=['mkdir', '-p', 'breakpad-out'])
+
+ # Breakpad requires C++11, so use clang and the sysroot rather than
+ # hoping that the host toolchain will provide support.
+ configure_args = []
+ if context.Linux():
+ cxx = 'CXX=../../third_party/llvm-build/Release+Asserts/bin/clang++ '
+ if context['arch'] == '32':
+ cxx += '-m32'
+ sysroot_arch = 'i386'
+ else:
+ cxx += '-m64'
+ sysroot_arch = 'amd64'
+ cxx += (' --sysroot=../../build/linux/debian_wheezy_%s-sysroot' %
+ sysroot_arch)
+ configure_args += [cxx]
+ configure_args += ['CXXFLAGS=-I../..'] # For third_party/lss
Command(context, cwd='breakpad-out',
- cmd=['bash', '../../breakpad/configure',
- 'CXXFLAGS=-I../..']) # For third_party/lss
+ cmd=['bash', '../../breakpad/configure'] + configure_args)
+
with Step('breakpad make', status):
Command(context, cmd=['make', '-j%d' % context['max_jobs'],
# This avoids a broken dependency on
@@ -334,7 +334,8 @@ def BuildScript(status, context):
CommandGclientRunhooks(context)
# Always update Clang. On Linux and Mac, it's the default for the GN build.
- # On Windows, we do a second Clang GN build.
+ # It's also used for the Linux Breakpad build. On Windows, we do a second
+ # Clang GN build.
with Step('update_clang', status):
Command(context, cmd=[sys.executable, '../tools/clang/scripts/update.py'])
« no previous file with comments | « DEPS ('k') | src/trusted/service_runtime/linux/nacl_bootstrap.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698